@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * Copyright (c) 2012-2015 Kohei Yoshida
+ * Copyright (c) 2012-2018 Kohei Yoshida
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
@@ -25,14 +25,14 @@
  *
  ************************************************************************/
 
-#ifndef MDDS_MULTI_TYPE_VECTOR_ITR_HPP
-#define MDDS_MULTI_TYPE_VECTOR_ITR_HPP
+#ifndef INCLUDED_MDDS_MULTI_TYPE_VECTOR_ITR_HPP
+#define INCLUDED_MDDS_MULTI_TYPE_VECTOR_ITR_HPP
 
 #include "multi_type_vector_types.hpp"
 
 #include <cstddef>
 
-namespace mdds { namespace __mtv {
+namespace mdds { namespace detail { namespace mtv {
 
 /**
  * Node that represents the content of each iterator.  The private data part
@@ -54,9 +54,6 @@ struct iterator_value_node
     iterator_value_node(size_type start_pos, size_type block_index) :
         type(mdds::mtv::element_type_empty), position(start_pos), size(0), data(nullptr), __private_data(block_index) {}
 
-    iterator_value_node(const iterator_value_node& other) :
-        type(other.type), position(other.position), size(other.size), data(other.data), __private_data(other.__private_data) {}
-
     void swap(iterator_value_node& other)
     {
         std::swap(type, other.type);
@@ -168,14 +165,14 @@ protected:
             throw general_error("Current node position should never equal the end position during node update.");
 #endif
         // blocks_type::value_type is a pointer to multi_type_vector::block.
-        typename blocks_type::value_type blk = *m_pos;
-        if (blk->mp_data)
-            m_cur_node.type = mdds::mtv::get_block_type(*blk->mp_data);
+        const typename blocks_type::value_type& blk = *m_pos;
+        if (blk.mp_data)
+            m_cur_node.type = mdds::mtv::get_block_type(*blk.mp_data);
         else
             m_cur_node.type = mdds::mtv::element_type_empty;
 
-        m_cur_node.size = blk->m_size;
-        m_cur_node.data = blk->mp_data;
+        m_cur_node.size = blk.m_size;
+        m_cur_node.data = blk.mp_data;
     }
 
     node* inc()
@@ -272,9 +269,6 @@ public:
         size_type start_pos, size_type block_index) :
         common_base(pos, end, start_pos, block_index) {}
 
-    iterator_base(const iterator_base& other) :
-        common_base(other) {}
-
     value_type& operator*()
     {
         return m_cur_node;
@@ -345,9 +339,6 @@ public:
         size_type start_pos, size_type block_index) :
         common_base(pos, end, start_pos, block_index) {}
 
-    const_iterator_base(const const_iterator_base& other) :
-        common_base(other) {}
-
     /**
      * Take the non-const iterator counterpart to create a const iterator.
      */
@@ -392,6 +383,6 @@ public:
     }
 };
 
-}}
+}}}
 
 #endif
